pub enum SopsEncryptError {
EmptyPublicKey,
ParseRecipient(String),
EncryptValue(String),
EncryptMac(String),
WrapDataKey(String),
Marshal(String),
}Expand description
Errors returned by encrypt_for_secret.
Variants
EmptyPublicKey
encrypt_for_secret was called with an empty public key.
ParseRecipient(String)
The supplied public key is not a parseable age (X25519) recipient.
EncryptValue(String)
Encrypting the value leaf failed.
EncryptMac(String)
Encrypting the MAC failed.
WrapDataKey(String)
Wrapping the data key to the age recipient failed.
Marshal(String)
Serializing the SOPS document to YAML failed.